@@ -8,7 +8,6 @@ import sys
 from contextlib import contextmanager
 
 import multivolumefile
-import psutil  # type: ignore
 import pytest
 
 import py7zr
@@ -176,11 +175,13 @@ def limit_memory(maxsize: int):
     :param maxsize: Maximum size of memory resource to limit
     :raises: MemoryError: When function reaches the limit.
     """
-    if sys.platform.startswith("win"):
+    if sys.platform.startswith("win") or sys.platform.startswith("cygwin"):
         yield
     else:
         import resource
 
+        import psutil  # type: ignore
+
         soft, hard = resource.getrlimit(resource.RLIMIT_AS)
         soft_new = psutil.Process(os.getpid()).memory_info().rss + maxsize
         if soft == -1 or soft_new < soft:
